@@ -73,13 +73,14 @@ def pack_log(input_args):
             input_args, download_log=True, recursive=input_args.recursive
         )
     )
-    print(f"log_files: {log_files}")
+
+    print(f"\r\nlog_files: {log_files}")
 
     if len(log_files) == 0:
         print("no log files in range")
         return
 
-    print(f"totlal {len(log_files)} files, compress start ...")
+    print(f"\r\ntotlal {len(log_files)} files, compress start ...")
 
     # get current datetime like 20210913175500
     cur_datetime = datetime.now().strftime("%Y%m%d%H%M%S")
